@@ -1,7 +1,7 @@
 """
 Helper methods for running and documenting processors
 """
-from os import environ
+from os import chdir, environ, getcwd
 from time import perf_counter, process_time
 from functools import lru_cache
 import json
@@ -14,7 +14,7 @@ from sparklines import sparklines
 
 from click import wrap_text
 from ocrd.workspace import Workspace
-from ocrd_utils import freeze_args, getLogger
+from ocrd_utils import freeze_args, getLogger, pushd_popd
 
 
 __all__ = [
@@ -35,7 +35,6 @@ def _get_workspace(workspace=None, resolver=None, mets_url=None, working_dir=Non
 
 def run_processor(
         processorClass,
-        ocrd_tool=None,
         mets_url=None,
         resolver=None,
         workspace=None,
@@ -59,7 +58,6 @@ def run_processor(
 
     Instantiate a Python object for :py:attr:`processorClass`, passing:
     - the workspace,
-    - :py:attr:`ocrd_tool`
     - :py:attr:`page_id`
     - :py:attr:`input_file_grp`
     - :py:attr:`output_file_grp`
@@ -84,16 +82,18 @@ def run_processor(
     log = getLogger('ocrd.processor.helpers.run_processor')
     log.debug("Running processor %s", processorClass)
 
+    old_cwd = getcwd()
     processor = get_processor(
         processor_class=processorClass,
         parameter=parameter,
         workspace=workspace,
-        ocrd_tool=ocrd_tool,
         page_id=page_id,
         input_file_grp=input_file_grp,
         output_file_grp=output_file_grp,
         instance_caching=instance_caching
     )
+    processor.workspace = workspace
+    chdir(processor.workspace.directory)
 
     ocrd_tool = processor.ocrd_tool
     name = '%s v%s' % (ocrd_tool['executable'], processor.version)
@@ -104,31 +104,44 @@ def run_processor(
     t0_cpu = process_time()
     if any(x in environ.get('OCRD_PROFILE', '') for x in ['RSS', 'PSS']):
         backend = 'psutil_pss' if 'PSS' in environ['OCRD_PROFILE'] else 'psutil'
-        mem_usage = memory_usage(proc=processor.process,
-                                # only run process once
-                                max_iterations=1,
-                                interval=.1, timeout=None, timestamps=True, 
-                                # include sub-processes
-                                multiprocess=True, include_children=True, 
-                                # get proportional set size instead of RSS
-                                backend=backend)
+        try:
+            mem_usage = memory_usage(proc=processor.process,
+                                     # only run process once
+                                     max_iterations=1,
+                                     interval=.1, timeout=None, timestamps=True,
+                                     # include sub-processes
+                                     multiprocess=True, include_children=True,
+                                     # get proportional set size instead of RSS
+                                     backend=backend)
+        except Exception as err:
+            log.exception("Failure in processor '%s'" % ocrd_tool['executable'])
+            raise err
+        finally:
+            chdir(old_cwd)
         mem_usage_values = [mem for mem, _ in mem_usage]
         mem_output = 'memory consumption: '
         mem_output += ''.join(sparklines(mem_usage_values))
         mem_output += ' max: %.2f MiB min: %.2f MiB' % (max(mem_usage_values), min(mem_usage_values))
         logProfile.info(mem_output)
     else:
-        processor.process()
+        try:
+            processor.process()
+        except Exception as err:
+            log.exception("Failure in processor '%s'" % ocrd_tool['executable'])
+            raise err
+        finally:
+            chdir(old_cwd)
+
     t1_wall = perf_counter() - t0_wall
     t1_cpu = process_time() - t0_cpu
     logProfile.info("Executing processor '%s' took %fs (wall) %fs (CPU)( [--input-file-grp='%s' --output-file-grp='%s' --parameter='%s' --page-id='%s']" % (
         ocrd_tool['executable'],
         t1_wall,
         t1_cpu,
-        input_file_grp or '',
-        output_file_grp or '',
-        json.dumps(parameter) or '',
-        page_id or ''
+        processor.input_file_grp or '',
+        processor.output_file_grp or '',
+        json.dumps(processor.parameter) or '',
+        processor.page_id or ''
     ))
     workspace.mets.add_agent(
         name=name,
@@ -136,14 +149,15 @@ def run_processor(
         othertype='SOFTWARE',
         role='OTHER',
         otherrole=otherrole,
-        notes=[({'option': 'input-file-grp'}, input_file_grp or ''),
-               ({'option': 'output-file-grp'}, output_file_grp or ''),
-               ({'option': 'parameter'}, json.dumps(parameter or '')),
-               ({'option': 'page-id'}, page_id or '')]
+        notes=[({'option': 'input-file-grp'}, processor.input_file_grp or ''),
+               ({'option': 'output-file-grp'}, processor.output_file_grp or ''),
+               ({'option': 'parameter'}, json.dumps(processor.parameter or '')),
+               ({'option': 'page-id'}, processor.page_id or '')]
     )
     workspace.save_mets()
     return processor
 
+
 def run_cli(
         executable,
         mets_url=None,
@@ -303,7 +317,6 @@ def get_processor(
         processor_class,
         parameter: dict,
         workspace: Workspace = None,
-        ocrd_tool: dict = None,
         page_id: str = None,
         input_file_grp: List[str] = None,
         output_file_grp: List[str] = None,
@@ -322,7 +335,6 @@ def get_processor(
             return cached_processor
         return processor_class(
             workspace=workspace,
-            ocrd_tool=ocrd_tool,
             page_id=page_id,
             input_file_grp=input_file_grp,
             output_file_grp=output_file_grp,
